@@ -45,6 +45,8 @@ class ExceptionDialog(gtk.Dialog):
         self.msg_vbox = gtk.VBox()
         vbox.pack_start(self.msg_vbox)
         self.g_primary = gtk.Label()
+        if sys.exc_info()[0].__name__ == 'AttributeError':
+            self.g_primary.set_name("DEBUGWARNING")
         self.g_primary.set_alignment(0.0, 0.5)
         self.g_primary.set_line_wrap(True)
         self.m_primary_bold = False
