@@ -223,7 +223,7 @@ class DB(object):
                         """
                         d, f = os.path.split(filename)
                         fn = os.path.join(subdir, f)
-                        if (d == 'exercises%slesson-files' % os.sep
+                        if (d == 'exercises%sstandard%slesson-files' % (os.sep, os.sep)
                             and os.path.isfile(fn)):
                             return fn
                         return filename
@@ -345,22 +345,32 @@ class DB(object):
         else:
             hashvalue, fileid = row
             if hashvalue != cur_lessonfile_hash_value:
-                cursor.execute("delete from sessions where fileid=?", (fileid,))
-                cursor.execute("delete from tests where fileid=?", (fileid,))
-                cursor.execute("update lessonfiles "
-                    "set hash=?, test_passed=?, test_result=0.0 where fileid=?",
-                    (cur_lessonfile_hash_value, None, fileid))
-                self.conn.commit()
-    def recent(self, count):
+                replaces = solfege.lessonfile.infocache.get(filename, 'replaces')
+                if not isinstance(replaces, list):
+                    replaces = [replaces]
+                if not hashvalue in replaces:
+                    cursor.execute("delete from sessions where fileid=?", (fileid,))
+                    cursor.execute("delete from tests where fileid=?", (fileid,))
+                    cursor.execute("update lessonfiles "
+                        "set hash=?, test_passed=?, test_result=0.0 where fileid=?",
+                        (cur_lessonfile_hash_value, None, fileid))
+                    self.conn.commit()
+    def _recent(self, count, tablename):
+        assert tablename in ('sessions', 'tests')
         filenames = []
-        for fileid, timestamp in self.conn.execute('select fileid, timestamp from sessions '
-                'order by -timestamp'):
+        for fileid, timestamp in self.conn.execute(
+                'select fileid, timestamp from %s '
+                'order by -timestamp' % tablename):
             filename = self.conn.execute('select filename from lessonfiles where fileid=?', (fileid,)).fetchone()[0]
             if filename not in filenames:
                 filenames.append(filename)
             if len(filenames) == count:
                 break
         return filenames
+    def recent(self, count):
+        return self._recent(count, 'sessions')
+    def recent_tests(self, count):
+        return self._recent(count, 'tests')
     def set_variable(self, name, value):
         """
         raise DB.VariableTypeError if the type we set is different from
@@ -462,7 +472,6 @@ class AbstractStatistics(object):
         Start a new practise session.
         """
         self.m_timestamp = int(time.time())
-        rows = solfege.db.conn.execute("select * from lessonfiles where filename=?", (self.m_t.m_P.m_filename,)).fetchall()
     def enter_test_mode(self):
         self.m_test_mode = True
     def exit_test_mode(self):
@@ -522,7 +531,9 @@ class AbstractStatistics(object):
         correct in this session
         """
         fileid = solfege.db.get_fileid(self.m_t.m_P.m_filename)
+        fileid = ["None"]
         num_correct = solfege.db.conn.execute("select sum(count) from sessions where answerkey=guessed and timestamp=? and fileid=?", (self.m_timestamp, fileid)).fetchone()[0]
+        print "Num", num_correct
         num_asked = solfege.db.conn.execute("select sum(count) from sessions where timestamp=? and  fileid=?", (self.m_timestamp, fileid)).fetchone()[0]
         if not num_correct:
             num_correct = 0
@@ -589,10 +600,13 @@ class LessonStatistics(AbstractStatistics):
         return ff(key)
 
 class IntervalStatistics(AbstractStatistics):
+    def get_keys(self, all_keys=False):
+        v = AbstractStatistics.get_keys(self, all_keys)
+        return [int(x) for x in v]
     def key_to_pretty_name(self, key):
         return utils.int_to_intervalname(int(key), 1, 1)
 
-class HarmonicIntervalStatistics(AbstractStatistics):
+class HarmonicIntervalStatistics(IntervalStatistics):
     def key_to_pretty_name(self, key):
         return utils.int_to_intervalname(int(key), 1, 0)
 
